@@ -867,13 +867,10 @@ gboolean
 libbalsa_filter_export_sieve(LibBalsaFilter* fil, gchar* filename)
 {
     FILE * fp;
-    GString * buffer;
     gint nb = 0;
 
     fp=fopen(filename,"w");
     if (!fp) return FALSE;
-    buffer=g_string_new("# Sieve script automatically generated by Balsa "
-                        "(Exporting a Balsa filter)\n");
     g_warning("%s: FIXME!\n", __func__);
 #if 0
     
