@@ -23,10 +23,14 @@
 #ifndef __LIBBALSA_PRIVATE_H__
 #define __LIBBALSA_PRIVATE_H__
 
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
 #include <unistd.h>
 
 /* LibBalsaMailboxEntry handling code which is to be used for message
- * intex caching.  Mailbox index entry used for caching (almost) all
+ * index caching.  Mailbox index entry used for caching (almost) all
  * columns provided by GtkTreeModel interface. Size matters. */
 struct LibBalsaMailboxIndexEntry_ {
     gchar *from;
@@ -36,6 +40,10 @@ struct LibBalsaMailboxIndexEntry_ {
     unsigned short status_icon;
     unsigned short attach_icon;
     unsigned long size;
+    gchar *foreground;
+    gchar *background;
+    unsigned foreground_set:1;
+    unsigned background_set:1;
     unsigned unseen:1;
 #ifdef BALSA_USE_THREADS
     unsigned idle_pending:1;
@@ -44,7 +52,6 @@ struct LibBalsaMailboxIndexEntry_ {
 
 #ifdef BALSA_USE_THREADS
 #include <pthread.h>
-extern pthread_mutex_t mailbox_lock;
 void libbalsa_lock_mailbox(LibBalsaMailbox * mailbox);
 void libbalsa_unlock_mailbox(LibBalsaMailbox * mailbox);
 #else
