@@ -27,12 +27,14 @@
 
 #include "libbalsa.h"
 
+typedef void (*LibBalsaCharsetFunc) (const gchar * charset, gpointer data);
+
 GString *process_mime_part(LibBalsaMessage * message,
 			   LibBalsaMessageBody * body,
 			   gchar * reply_prefix_str, gint llen,
 			   gboolean ignore_html, gboolean flow);
-GString *content2reply(LibBalsaMessage * message,
+GString *content2reply(LibBalsaMessageBody *root,
 		       gchar * reply_prefix_str, gint llen,
-		       gboolean ignore_html, gboolean flow);	/* arp */
+		       gboolean ignore_html, gboolean flow);
 
 #endif				/* __LIBBALSA_MIME_H__ */
