@@ -22,11 +22,18 @@
 #ifndef __RFC3156_H__
 #define __RFC3156_H__
 
-#include "config.h"
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
+
+/* bits to define the protection method; needed even when we don't
+ * HAVE_GPGME */
+#define LIBBALSA_PROTECT_OPENPGP       (1 << 2)	/* RFC 2440 (OpenPGP) */
+#define LIBBALSA_PROTECT_SMIMEV3       (1 << 3)	/* RFC 2633 (S/MIME v3) */
+#define LIBBALSA_PROTECT_RFC3156       (1 << 4)	/* RFC 3156 (PGP/MIME) */
 
 #ifdef HAVE_GPGME
 
-#include <gnome.h>
 #include <gpgme.h>
 #include "libbalsa.h"
 #include "misc.h"
@@ -34,18 +41,18 @@
 
 
 /* bits to define the protection mode: signed or encrypted */
-#define LIBBALSA_PROTECT_SIGN      (1 << 0)
-#define LIBBALSA_PROTECT_ENCRYPT   (1 << 1)
-#define LIBBALSA_PROTECT_MODE      (3 << 0)
+#define LIBBALSA_PROTECT_SIGN          (1 << 0)
+#define LIBBALSA_PROTECT_ENCRYPT       (1 << 1)
+#define LIBBALSA_PROTECT_MODE          (3 << 0)
 
 /* bits to define the protection method */
-#define LIBBALSA_PROTECT_OPENPGP   (1 << 2)	/* RFC 2440 (OpenPGP) */
-#define LIBBALSA_PROTECT_SMIMEV3   (1 << 3)	/* RFC 2633 (S/MIME v3) */
-#define LIBBALSA_PROTECT_RFC3156   (1 << 4)	/* RFC 3156 (PGP/MIME) */
-#define LIBBALSA_PROTECT_PROTOCOL  (7 << 2)
+#define LIBBALSA_PROTECT_PROTOCOL      (7 << 2)
 
 /* indicate broken structure */
-#define LIBBALSA_PROTECT_ERROR     (1 << 5)
+#define LIBBALSA_PROTECT_ERROR         (1 << 5)
+
+/* indicate that uid's should always be trusted */
+#define LIBBALSA_PROTECT_ALWAYS_TRUST  (1 << 6)
 
 
 /* some custom error messages */
@@ -56,21 +63,28 @@
 gboolean libbalsa_check_crypto_engine(gpgme_protocol_t protocol);
 
 gint libbalsa_message_body_protection(LibBalsaMessageBody * body);
+gboolean libbalsa_can_encrypt_for_all(InternetAddressList * recipients,
+				      gpgme_protocol_t protocol);
 
 /* routines dealing with RFC 2633 and RFC 3156 stuff */
 gboolean libbalsa_sign_mime_object(GMimeObject ** content,
 				   const gchar * rfc822_for,
 				   gpgme_protocol_t protocol,
-				   GtkWindow * parent);
+				   GtkWindow * parent,
+				   GError ** error);
 gboolean libbalsa_encrypt_mime_object(GMimeObject ** content,
 				      GList * rfc822_for,
 				      gpgme_protocol_t protocol,
-				      GtkWindow * parent);
+				      gboolean always_trust,
+				      GtkWindow * parent,
+				      GError ** error);
 gboolean libbalsa_sign_encrypt_mime_object(GMimeObject ** content,
 					   const gchar * rfc822_signer,
 					   GList * rfc822_for,
 					   gpgme_protocol_t protocol,
-					   GtkWindow * parent);
+					   gboolean always_trust,
+					   GtkWindow * parent,
+					   GError ** error);
 gboolean libbalsa_body_check_signature(LibBalsaMessageBody * body,
 				       gpgme_protocol_t protocol);
 LibBalsaMessageBody *libbalsa_body_decrypt(LibBalsaMessageBody * body,
@@ -81,7 +95,9 @@ LibBalsaMessageBody *libbalsa_body_decrypt(LibBalsaMessageBody * body,
 gboolean libbalsa_rfc2440_sign_encrypt(GMimePart * part,
 				       const gchar * sign_for,
 				       GList * encrypt_for,
-				       GtkWindow * parent);
+				       gboolean always_trust,
+				       GtkWindow * parent,
+				       GError ** error);
 gpgme_error_t libbalsa_rfc2440_verify(GMimePart * part,
 				      GMimeGpgmeSigstat ** sig_info);
 gpgme_error_t libbalsa_rfc2440_decrypt(GMimePart * part,
@@ -96,7 +112,15 @@ gchar *libbalsa_signature_info_to_gchar(GMimeGpgmeSigstat * info,
 					const gchar * date_string);
 
 #ifdef HAVE_GPG
-gboolean gpg_run_import_key(const gchar * fingerprint, GtkWindow * parent);
+
+typedef enum {
+    GPG_KEYSERVER_IMPORT = 1,
+    GPG_KEYSERVER_UPDATE
+} gpg_keyserver_action_t;
+
+gboolean gpg_keyserver_op(const gchar * fingerprint,
+                          gpg_keyserver_action_t action,
+                          GtkWindow * parent);
 
 #endif
 #endif				/* HAVE_GPGME */
