@@ -339,6 +339,7 @@ balsa_app_init(void)
     balsa_app.show_notebook_tabs = FALSE;
     balsa_app.layout_type = LAYOUT_DEFAULT;
     balsa_app.view_message_on_open = TRUE;
+    balsa_app.ask_before_select = FALSE;
     balsa_app.mw_action_after_move = NEXT_UNREAD;
 
     balsa_app.index_num_width = NUM_DEFAULT_WIDTH;
@@ -466,7 +467,12 @@ balsa_app_destroy(void)
     g_slist_free(balsa_app.filters);
     balsa_app.filters = NULL;
 
-    /* g_slist_free(opt_attach_list); */
+
+    g_list_foreach(balsa_app.identities, (GFunc)g_object_unref, NULL);
+    g_list_free(balsa_app.identities);
+    balsa_app.identities = NULL;
+
+
     g_object_unref(balsa_app.colormap);
     if(balsa_app.debug) g_print("balsa_app: Finished cleaning up.\n");
 }
@@ -513,7 +519,7 @@ append_url_if_open(const gchar * url, LibBalsaMailboxView * view,
 }
 
 static void
-open_mailbox_by_url(const gchar * url)
+open_mailbox_by_url(const gchar * url, gboolean hidden)
 {
     LibBalsaMailbox *mailbox;
 
@@ -524,11 +530,12 @@ open_mailbox_by_url(const gchar * url)
     if (balsa_app.debug)
         fprintf(stderr, "open_mailboxes_idle_cb: opening %s => %p..\n",
                 url, mailbox);
-    if (mailbox)
-        /* The first mailbox we open will be shown; later mailboxes will
-         * have notebook pages, but will not be shown. */
-        balsa_mblist_open_mailbox_hidden(mailbox);
-    else {
+    if (mailbox) {
+        if (hidden)
+            balsa_mblist_open_mailbox_hidden(mailbox);
+        else
+            balsa_mblist_open_mailbox(mailbox);
+    } else {
         /* Do not try to open it next time. */
         LibBalsaMailboxView *view =
             g_hash_table_lookup(libbalsa_mailbox_view_table, url);
@@ -569,10 +576,12 @@ open_mailboxes_idle_cb(gchar ** urls)
 
     if (urls) {
         if (*urls) {
-            open_mailbox_by_url(balsa_app.current_mailbox_url);
+            open_mailbox_by_url(balsa_app.current_mailbox_url, FALSE);
 
             for (tmp = urls; *tmp; ++tmp)
-                open_mailbox_by_url(*tmp);
+                if (!balsa_app.current_mailbox_url
+                    || strcmp(*tmp, balsa_app.current_mailbox_url))
+                    open_mailbox_by_url(*tmp, TRUE);
         }
 
         g_strfreev(urls);
