@@ -42,17 +42,12 @@
 typedef struct _option_list {
     gchar *text;
     gint value;
-#if !GTK_CHECK_VERSION(2, 4, 0)
-    GtkWidget *widget;
-#endif /* GTK_CHECK_VERSION(2, 4, 0) */
 } option_list;
 
-#if GTK_CHECK_VERSION(2, 4, 0)
 struct fe_combo_box_info {
     GSList *values;
 };
 #define BALSA_FE_COMBO_BOX_INFO "balsa-fe-combo-box-info"
-#endif /* GTK_CHECK_VERSION(2, 4, 0) */
 
 /* destroy calback */
 void fe_destroy_window_cb(GtkWidget *,gpointer);
@@ -63,7 +58,7 @@ void fe_dialog_response(GtkWidget * widget, gint response,
 
 /* helper */
 GtkWidget *fe_build_option_menu(option_list options[], gint num,
-                                GCallback func);
+                                GCallback func, gpointer cb_data);
 
 /*---------------- Left side of hbox ----------------*/
 
@@ -99,5 +94,13 @@ void fe_button_toggled(GtkWidget * widget, gpointer data);
 void fe_action_changed(GtkWidget * widget, gpointer data);
 void fe_enable_right_page(gboolean enabled);
 
+/* Callback for the sound file-chooser-button's dialog. */
+void fe_sound_response(GtkDialog * dialog, gint response);
+
 void fe_add_new_user_header(const gchar *);
+
+/* Callbacks for color button signals */
+void fe_color_check_toggled(GtkToggleButton * check_button, gpointer data);
+void fe_color_set(GtkColorButton * color_button, gpointer data);
+
 #endif /*__FILTER_EDIT_H__ */
