@@ -22,16 +22,16 @@
 #ifndef __PRINT_H__
 #define __PRINT_H__
 
-#include "config.h"
+#ifndef BALSA_VERSION
+# error "Include config.h before this file."
+#endif
 
 #ifdef __cplusplus
 extern "C" {
 #endif				/* __cplusplus */
 
     void message_print(LibBalsaMessage * msg, GtkWindow * parent);
-#ifdef HAVE_GTK_PRINT
     void message_print_page_setup(GtkWindow * parent);
-#endif
 
 #ifdef __cplusplus
 }
